SystemOrganization addCategory: #ConfigurationOfPolySource!

Object subclass: #ConfigurationOfPolySource
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfPolySource'!

!ConfigurationOfPolySource class methodsFor: 'private' stamp: 'mt 10/6/2010 17:19:40.106'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfPolySource class methodsFor: 'private' stamp: 'mt 10/6/2010 17:19:40.196'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfPolySource class methodsFor: 'metacello tool support' stamp: 'mt 10/6/2010 17:19:40.286'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfPolySource class methodsFor: 'metacello tool support' stamp: 'mt 10/6/2010 17:19:40.404'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfPolySource class methodsFor: 'loading' stamp: 'mt 10/6/2010 17:19:40.56'!
load
	"self load"

	^self project stableVersion load! !

!ConfigurationOfPolySource class methodsFor: 'metacello tool support' stamp: 'mt 10/6/2010 17:19:40.466'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfPolySource class methodsFor: 'accessing' stamp: 'mt 10/6/2010 17:19:40.644'!
project

	^self new project! !

!ConfigurationOfPolySource class methodsFor: 'unloading Metacello' stamp: 'mt 10/6/2010 17:19:40.752'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfPolySource methodsFor: 'baselines' stamp: 'mt 10/6/2010 17:23:07.849'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'.

		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'SqSync' with: [
			spec
				className: 'ConfigurationOfSqSync';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec package: 'ProcessSpecific' with: [
			spec repository: 'http://www.squeaksource.com/ProcessLocalStorage'].

		spec
			package: 'MethodWrappers';
			package: 'PolySource' with: [spec requires: #('SqSync' 'MethodWrappers' 'Signals' 'ProcessSpecific' 'Animations' 'Widgets')].
		spec
			group: 'default' with: #('PolySource')].! !

!ConfigurationOfPolySource methodsFor: 'accessing' stamp: 'mt 10/6/2010 17:19:39.908'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfPolySource methodsFor: 'versions' stamp: 'mt 10/6/2010 17:23:44.279'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		
		spec package: 'PolySource' with: 'PolySource-mt.89'].! !
